pub enum ScalarValue<'de> {
Unit,
Null,
Bool(bool),
Char(char),
I64(i64),
U64(u64),
I128(i128),
U128(u128),
F64(f64),
Str(Cow<'de, str>),
Bytes(Cow<'de, [u8]>),
}Expand description
Scalar data extracted from the wire format.
Variants
Unit
Unit type (Rust’s ()).
Null
Null literal.
Bool(bool)
Boolean literal.
Char(char)
Character literal.
I64(i64)
Signed integer literal (fits in i64).
U64(u64)
Unsigned integer literal (fits in u64).
I128(i128)
Signed 128-bit integer literal.
U128(u128)
Unsigned 128-bit integer literal.
F64(f64)
Floating-point literal.
Str(Cow<'de, str>)
UTF-8 string literal.
Bytes(Cow<'de, [u8]>)
Binary literal.
Implementations
Sourceimpl<'de> ScalarValue<'de>
impl<'de> ScalarValue<'de>
Sourcepub fn to_string_value(&self) -> Option<String>
pub fn to_string_value(&self) -> Option<String>
Convert scalar value to a string representation.
This is a non-generic helper extracted to reduce monomorphization bloat.
Returns None for Bytes since that conversion is context-dependent.
Sourcepub fn to_display_string(&self) -> String
pub fn to_display_string(&self) -> String
Convert scalar value to a display string for error messages.
This is a non-generic helper extracted to reduce monomorphization bloat.