pub struct ParseError {
pub span: Span,
pub kind: DeserializeErrorKind,
}Expand description
Error produced by a format parser (JSON, TOML, etc.).
Parse errors always have a span (location in the input) but never have a path (location in the type structure) because parsers don’t know about the target type.
When propagated through the deserializer, this is converted to a DeserializeError
which can add path information.
Fields
span: SpanSource span where the error occurred.
kind: DeserializeErrorKindThe specific kind of error.
Implementations
Sourceimpl ParseError
impl ParseError
Sourcepub const fn new(span: Span, kind: DeserializeErrorKind) -> Self
pub const fn new(span: Span, kind: DeserializeErrorKind) -> Self
Create a new parse error with the given span and kind.