pub struct ParseEvent<'de> {
pub kind: ParseEventKind<'de>,
pub span: Span,
pub meta: Option<ValueMeta<'de>>,
}Expand description
Event emitted by a format parser while streaming through input.
Fields
kind: ParseEventKind<'de>The kind of event.
span: SpanSource span of this event in the input.
meta: Option<ValueMeta<'de>>Optional metadata (doc comments, type tags) attached to this value.
For most formats (JSON, TOML, etc.) this will be None. Formats like Styx
that support documentation comments and type tags on values will populate this.
Implementations
Sourceimpl<'de> ParseEvent<'de>
impl<'de> ParseEvent<'de>
Sourcepub fn new(kind: ParseEventKind<'de>, span: Span) -> Self
pub fn new(kind: ParseEventKind<'de>, span: Span) -> Self
Create a new event with the given kind and span.
Sourcepub fn with_meta(
self,
f: impl FnOnce(ValueMetaBuilder<'de>) -> ValueMetaBuilder<'de>,
) -> Self
pub fn with_meta( self, f: impl FnOnce(ValueMetaBuilder<'de>) -> ValueMetaBuilder<'de>, ) -> Self