SavePoint

Struct SavePoint 

pub struct SavePoint(pub u64);
Opaque token returned by FormatParser::save.

This token can be passed to FormatParser::restore to replay all events that were consumed since the save point.

Tuple Fields

0: u64

Implementations

Source

impl SavePoint

pub fn new(id: u64) -> Self

Create a new save point with the given ID.